﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using StoreMVC.Models;

namespace StoreMVC.Controllers
{
    public class OrderController : Controller
    {
        //
        // GET: /Order/
        private StoreDBEntities db;

        public OrderController()
        {
            db = new StoreDBEntities();
        }

        public ActionResult Index()
        {
            return View(db.Orders.ToList());
        }

        //
        // GET: /Order/Details/5

        public ActionResult Details(long id)
        {
            return View(db.Orders.First(x => x.Id == id));
        }

        //
        // GET: /Order/Create

        public ActionResult Create()
        {
            ViewBag.ProductId = new SelectList(db.Products.OrderBy(x => x.Name), "Id", "Name");
            return View();
        } 

        //
        // POST: /Order/Create

        [HttpPost]
        public ActionResult Create(long productId, DateTime date)
        {
            try
            {
                var order = new Order();
                order.ProductId = productId;
                order.Date = date;

                db.AddToOrders(order);

                db.SaveChanges();

                return RedirectToAction("Index");
            }
            catch
            {
                return RedirectToAction("Create");
            }
        }
        
        //
        // GET: /Order/Edit/5
 
        public ActionResult Edit(long id)
        {
            var order = db.Orders.First(x => x.Id == id);
            ViewBag.ProductId = new SelectList(db.Products, "Id", "Name", order.ProductId);

            return View(order);
        }

        //
        // POST: /Order/Edit/5

        [HttpPost]
        public ActionResult Edit(Order orderToEdit)
        {
            try
            {
                var orderOriginal = db.Orders.First(x => x.Id == orderToEdit.Id);
                db.ApplyCurrentValues(orderOriginal.EntityKey.EntitySetName, orderToEdit);

                db.SaveChanges();
 
                return RedirectToAction("Index");
            }
            catch
            {
                var order = db.Orders.First(x => x.Id == orderToEdit.Id);
                ViewBag.ProductId = new SelectList(db.Products, "Id", "Name", order.ProductId);

                return View();
            }
        }

        //
        // GET: /Order/Delete/5
 
        public ActionResult Delete()
        {
            return View();
        }

        [HttpPost]
        public ActionResult Delete(long id)
        {
            try
            {
                var orderToDelete = db.Orders.First(x => x.Id == id);
                db.DeleteObject(orderToDelete);
                db.SaveChanges();

                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }
    }
}
