﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using StoreMVC.Models;

namespace StoreMVC.Controllers
{
    [Authorize(Roles = "Admin")]
    public class ProductController : Controller
    {
        //
        // GET: /Product/
        private StoreDBEntities db;

        public ProductController()
        {
            db = new StoreDBEntities();
        }

        public ActionResult Index()
        {
            return View(db.Products.ToList());
        }

        //
        // GET: /Product/Details/5

        public ActionResult Details(long id)
        {
            return View(db.Products.First(x => x.Id == id));
        }

        //
        // GET: /Product/Create

        public ActionResult Create()
        {
            return View();
        }

        //
        // POST: /Product/Create

        [HttpPost]
        public ActionResult Create(Product product)
        {
            try
            {
                db.AddToProducts(product);

                db.SaveChanges();

                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }

        //
        // GET: /Product/Edit/5

        public ActionResult Edit(long id)
        {
            return View(db.Products.First(x => x.Id == id));
        }

        //
        // POST: /Product/Edit/5

        [HttpPost]
        public ActionResult Edit(Product productToEdit)
        {
            try
            {
                var productOriginal = db.Products.First(x => x.Id == productToEdit.Id);
                db.ApplyCurrentValues(productOriginal.EntityKey.EntitySetName, productToEdit);

                db.SaveChanges();

                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }

        //
        // GET: /Product/Delete/5

        public ActionResult Delete()
        {
            return View();
        }

        //
        // POST: /Default1/Delete/5

        [HttpPost]
        public ActionResult Delete(long id)
        {
            try
            {
                var produtToDelete = db.Products.First(x => x.Id == id);
                var ordersToDelete = produtToDelete.Orders;

                foreach (var order in ordersToDelete)
                {
                    db.DeleteObject(order);
                }

                db.DeleteObject(produtToDelete);
                db.SaveChanges();

                return RedirectToAction("Index");
            }
            catch
            {
                return View();
            }
        }
    } 
}
